History
=======

1.1.0 (2019-11-15)
------------------

* Support Python 3.8.

1.0.2 (2019-10-28)
------------------

* Update PyPI development status as active. This package is maintained again
  since I have started using it on a Python 2 compatible project :)

1.0.1 (2019-02-07)
------------------

* Update PyPI development status as inactive. This package is no longer
  maintained, see README.rst.

1.0.0 (2017-06-18)
------------------

* First release on PyPI, featuring ``kwargs_only`` decorator.
